# echelon-py: Echelon analysis in Python
[![License: Apache 2.0](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://github.com/takeshi-teshima/echelon-py/blob/master/LICENSE)
[![Documentation Coverage Rate Badge](./docs_src/coverage_badge.svg)](https://takeshi-teshima.github.io/echelon-py/index.html)
[![PyPI version](https://badge.fury.io/py/echelon-py.svg)](https://badge.fury.io/py/echelon-py)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/echelon-py)](https://takeshi-teshima.github.io/echelon-py/index.html)

![Logo](./docs_src/logo.svg)

## Install
`$ pip install echelon-py`

## Functionalities
- Echelon analysis
- Echelon dendrogram plot
- Echelon scan (detection of spatial clusters)

## Quick Start
Check out some [examples (echelon-py-examples)](https://takeshi-teshima.github.io/echelon-py-examples/)!

## How to Use
Check out the [documentation](https://takeshi-teshima.github.io/echelon-py/).

## Notes for Contributors
[Notes for Contributors](./README-dev.md).

## References
- R Package [‘echelon’](https://cran.r-project.org/web/packages/echelon/echelon.pdf)
